'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var pluginScaffolderBackend = require('@backstage/plugin-scaffolder-backend');
var clientNode = require('@kubernetes/client-node');
var yaml = require('js-yaml');

function _interopNamespace(e) {
	if (e && e.__esModule) return e;
	var n = Object.create(null);
	if (e) {
		Object.keys(e).forEach(function (k) {
			if (k !== 'default') {
				var d = Object.getOwnPropertyDescriptor(e, k);
				Object.defineProperty(n, k, d.get ? d : {
					enumerable: true,
					get: function () { return e[k]; }
				});
			}
		});
	}
	n["default"] = e;
	return Object.freeze(n);
}

var yaml__namespace = /*#__PURE__*/_interopNamespace(yaml);

const deployKubernetesAction = () => {
  return pluginScaffolderBackend.createTemplateAction({
    id: "kubernetes:apply-manifest",
    description: "Applies a Kubernetes manifest",
    schema: {
      input: {
        type: "object",
        properties: {
          manifest: {
            title: "Kubernetes Manifest",
            description: "YAML or JSON manifest for the Kubernetes resource to be applied",
            type: "string"
          },
          clusterUrl: {
            title: "Cluster URL",
            description: "URL of the Kubernetes API",
            type: "string"
          },
          token: {
            title: "Token",
            description: "Bearer token to authenticate with the Kubernetes API",
            type: "string"
          }
        },
        required: ["manifest", "clusterUrl", "token"]
      }
    },
    async handler(ctx) {
      var _a;
      const manifest = ctx.input.manifest;
      const clusterUrl = ctx.input.clusterUrl;
      const token = ctx.input.token;
      const kubeConfig = new clientNode.KubeConfig();
      kubeConfig.loadFromOptions({
        clusters: [
          {
            name: "dynamic-cluster",
            server: clusterUrl,
            skipTLSVerify: true
          }
        ],
        users: [
          {
            name: "dynamic-user",
            token
          }
        ],
        contexts: [
          {
            name: "dynamic-context",
            user: "dynamic-user",
            cluster: "dynamic-cluster"
          }
        ],
        currentContext: "dynamic-context"
      });
      const api = kubeConfig.makeApiClient(clientNode.KubernetesObjectApi);
      const resource = yaml__namespace.load(manifest);
      if (!resource || typeof resource !== "object") {
        throw new Error(
          "Invalid manifest: must be a valid YAML or JSON object"
        );
      }
      try {
        const result = await api.create(resource);
        ctx.logger.info(
          `Successfully applied manifest for ${resource.kind}/${(_a = resource.metadata) == null ? void 0 : _a.name}: ${result}`
        );
      } catch (error) {
        ctx.logger.error(`Failed to apply Kubernetes manifest: ${error}`);
        throw error;
      }
    }
  });
};

exports.deployKubernetesAction = deployKubernetesAction;
//# sourceMappingURL=index.cjs.js.map
